

set -ex



test ! -f "$PREFIX/lib/libMLIR$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_runner_utils$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_c_runner_utils$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_c_runner_utils_static.a"
test -f "$PREFIX/lib/libMLIR.so.14"
test -f "$PREFIX/lib/libmlir_runner_utils.so.14"
test -f "$PREFIX/lib/libmlir_c_runner_utils.so.14"
exit 0
